pub struct ReadCapture {
pub inventory: Vec<HostInventory>,
pub messages: Vec<SerializableMessage>,
}Expand description
A read capture is a parsed tarball that contains all of the messages and inventory for a given capture.
Currently this only loads the data into memory, but we might add additional helper methods in the future.
NOTE: The interior structure of the tarball is not a guaranteed API and may change in the future. All interactions should be done through this type
Fields
inventory: Vec<HostInventory>messages: Vec<SerializableMessage>Implementations