Module context

Module context 

Types and methods for handling wash contexts, the configuration files for interacting with lattices

Modules

fs
Implementations for managing contexts within a directory on a filesystem

Structs

WashContext

Constants

HOST_CONFIG_NAME

Traits

ContextManager
A trait that can be implemented by any type that wants to load, save, and otherwise manage wash contexts (e.g. from a database or a config store

Functions

default_component_operation_timeout_ms
Default timeout that should be used with operations that manipulate components (ex. scale)
default_timeout_ms