pub struct WashContext {Show 20 fields
pub name: String,
pub cluster_seed: Option<ClusterSeed>,
pub ctl_host: String,
pub ctl_port: u16,
pub ctl_jwt: Option<String>,
pub ctl_seed: Option<String>,
pub ctl_credsfile: Option<PathBuf>,
pub ctl_timeout: u64,
pub ctl_tls_ca_file: Option<PathBuf>,
pub ctl_tls_first: Option<bool>,
pub lattice: String,
pub js_domain: Option<String>,
pub rpc_host: String,
pub rpc_port: u16,
pub rpc_jwt: Option<String>,
pub rpc_seed: Option<String>,
pub rpc_credsfile: Option<PathBuf>,
pub rpc_timeout: u64,
pub rpc_tls_ca_file: Option<PathBuf>,
pub rpc_tls_first: Option<bool>,
}Fields
name: Stringcluster_seed: Option<ClusterSeed>ctl_host: Stringctl_port: u16ctl_jwt: Option<String>ctl_seed: Option<String>ctl_credsfile: Option<PathBuf>ctl_timeout: u64timeout in milliseconds
ctl_tls_ca_file: Option<PathBuf>TLS CA file to use for CTL
ctl_tls_first: Option<bool>Perform TLS handshake before expecting the server greeting for CTL
lattice: Stringjs_domain: Option<String>rpc_host: Stringrpc_port: u16rpc_jwt: Option<String>rpc_seed: Option<String>rpc_credsfile: Option<PathBuf>rpc_timeout: u64rpc timeout in milliseconds
rpc_tls_ca_file: Option<PathBuf>TLS CA file to use for RPC calls
rpc_tls_first: Option<bool>Perform TLS handshake before expecting the server greeting for RPC
Implementations