Module parser

Module parser 

Parse wasmcloud.toml files which specify key information for building and signing WebAssembly modules and native capability provider binaries

Structs

CommonConfig
Configuration common among all project types & languages.
ComponentConfig
DevConfig
Configuration for development environments and/or DX related plugins
DevManifestComponentTarget
Target that specifies a single component in a given manifest path
GoConfig
Configuration related to Golang configuration
InterfaceComponentOverride
Interface-based overrides used for a single component
InterfaceOverrides
Configuration for imports that should be overridden
OneOrMoreIterator
Iterator for OneOrMore
ProjectConfig
Project configuration, normally specified in the root keys of a wasmcloud.toml file
ProviderConfig
RegistryConfig
RegistryPullConfig
Configuration that governs pulling of packages from registries
RegistryPullSourceOverride
Information identifying a registry that can be pulled from
RegistryPushConfig
RustConfig
TinyGoConfig
WasmcloudDotToml
The wasmcloud.toml specification format as de-serialization friendly project configuration data
WitInterfaceSpec
String that represents a specification of a WIT interface (normally used when specifying InterfaceComponentOverrides)

Enums

DevConfigSpec
Specification for how to wire up configuration
DevSecretSpec
Specification for how to wire up secrets
LanguageConfig
OneOrMore
Facilitates one of a given T or more (primarily for serde use)
RegistryPullSource
Source for a registry pull
TinyGoGarbageCollector
TinyGoScheduler
TypeConfig
WasmTarget

Functions

load_config
Gets the wasmCloud project (component or provider) config.