pub struct WasmcloudDotToml {Show 16 fields
pub language: String,
pub project_type: String,
pub name: Option<String>,
pub version: Option<Version>,
pub revision: i32,
pub path: Option<PathBuf>,
pub wit: Option<PathBuf>,
pub build: Option<PathBuf>,
pub component: ComponentConfig,
pub provider: ProviderConfig,
pub rust: RustConfig,
pub tinygo: TinyGoConfig,
pub go: GoConfig,
pub dev: DevConfig,
pub package_config: Option<Config>,
pub registry: RegistryConfig,
}Expand description
The wasmcloud.toml specification format as de-serialization friendly project configuration data
This structure is normally directly de-serialized from wasmcloud.toml,
and is used to build a more structured ProjectConfig object.
Below is an example of each option in the wasmcloud.toml file. A real example only needs to include the fields that are relevant to the project.
use wash_lib::parser::WasmcloudDotToml;
let component_toml = r#"
language = "rust"
type = "component"
name = "testcomponent"
version = "0.1.0"
"#;
let config: WasmcloudDotToml = toml::from_str(component_toml).expect("should deserialize");
eprintln!("{config:?}");Fields
language: StringThe language of the project, e.g. rust, tinygo. This is used to determine which config to parse.
project_type: StringThe type of project. This is a string that is used to determine which type of config to parse. The toml file name is just “type” but is named project_type here to avoid clashing with the type keyword in Rust.
name: Option<String>Name of the project. Optional if building a Rust project, as it can be inferred from Cargo.toml.
version: Option<Version>Semantic version of the project. Optional if building a Rust project, as it can be inferred from Cargo.toml.
revision: i32Monotonically increasing revision number.
path: Option<PathBuf>Path to the directory where the project is located. Defaults to the current directory. This path is where build commands will be run.
wit: Option<PathBuf>Path to the directory where the WIT world and dependencies can be found. Defaults to a wit
directory in the project root.
build: Option<PathBuf>Path to the directory where the built artifacts should be written. Defaults to a build
directory in the project root.
component: ComponentConfigConfiguration relevant to components
provider: ProviderConfigConfiguration relevant to providers
rust: RustConfigRust configuration and options
tinygo: TinyGoConfigTinyGo related configuration and options
go: GoConfigGolang related configuration and options
dev: DevConfigConfiguration for development environments and/or DX related plugins
package_config: Option<Config>Overrides for interface dependencies.
This is often used to point to local wit files
registry: RegistryConfigConfiguration for image registry usage
Implementations
Sourceimpl WasmcloudDotToml
impl WasmcloudDotToml
pub fn convert(self, wasmcloud_toml_dir: PathBuf) -> Result<ProjectConfig>