Module wash_lib::plugin::subcommand

source ·

Structs

  • Host directory mapping to provide to plugins
  • The metadata for a plugin used for registration and setup
  • A struct that manages loading and running subcommand plugins