NatsConfig

Struct NatsConfig 

pub struct NatsConfig {
    pub host: String,
    pub port: u16,
    pub store_dir: PathBuf,
    pub js_domain: Option<String>,
    pub remote_url: Option<String>,
    pub credentials: Option<PathBuf>,
    pub websocket_port: u16,
    pub config_path: Option<PathBuf>,
}
Configuration for a NATS server that supports running either in “standalone” or “leaf” mode. See the respective NatsConfig::new_standalone and NatsConfig::new_leaf implementations below for more information.

Fields

host: Stringport: u16store_dir: PathBuf

The path where the NATS server will store its jetstream data. This must be different for each NATS server you spin up, otherwise they will share stream data

js_domain: Option<String>remote_url: Option<String>credentials: Option<PathBuf>websocket_port: u16config_path: Option<PathBuf>

Implementations

Source

impl NatsConfig

pub fn new_leaf( host: &str, port: u16, js_domain: Option<String>, remote_url: String, credentials: PathBuf, websocket_port: u16, config_path: Option<PathBuf>, ) -> Self

Instantiates config for a NATS leaf node. Leaf nodes are meant to extend an existing NATS infrastructure like Synadia’s NGS, but can also be used to extend your own NATS infrastructure. For more information, our Working with Leaf Nodes docs

Arguments
  • host: NATS host to listen on, e.g. 127.0.0.1
  • port: NATS port to listen on, e.g. 4222
  • js_domain: Jetstream domain to use, defaults to core. See Configuring Jetstream for more information
  • remote_url: URL of NATS cluster to extend
  • credentials: Credentials to authenticate to the existing NATS cluster
pub fn new_standalone(host: &str, port: u16, js_domain: Option<String>) -> Self

Instantiates config for a standalone NATS server. Unless you’re looking to extend existing NATS infrastructure, this is the preferred NATS server mode.

Arguments
  • host: NATS host to listen on, e.g. 127.0.0.1
  • port: NATS port to listen on, e.g. 4222
  • js_domain: Jetstream domain to use, defaults to core. See Configuring Jetstream for more information
pub async fn write_to_path<P>(self, path: P) -> Result<()>
where P: AsRef<Path>,