Module wait

Module wait 

Structs

ComponentStoppedInfo
Information related to an component stop
ProviderStartedInfo
Information related to an provider start
ProviderStoppedInfo
Information related to an provider stop

Enums

EventCheckOutcome
The potential outcomes of a function check on an event. Because we can pass events that are not applicable to the event we are looking for, we need the NotApplicable variant to skip these events.
FindEventOutcome
The potential outcomes of an event that has been found. It can either succeed or fail. This enum should only be returned if we found the applicable event. If we did not find the event or another error occurred, use the Err variant of a Result wrapping around this enum.

Functions

wait_for_component_scaled_event
Uses the NATS receiver to read events being published to the wasmCloud lattice event subject, up until the given timeout duration.
wait_for_component_stop_event
Uses the NATS receiver to read events being published to the wasmCloud lattice event subject, up until the given timeout duration.
wait_for_provider_start_event
Uses the NATS receiver to read events being published to the wasmCloud lattice event subject, up until the given timeout duration.
wait_for_provider_stop_event
Uses the NATS receiver to read events being published to the wasmCloud lattice event subject, up until the given timeout duration.