Function wash_lib::app::deploy_model
source · pub async fn deploy_model(
client: &Client,
lattice: Option<String>,
model_name: &str,
version: Option<String>,
) -> Result<(String, Option<String>)>Expand description
Deploy a model, instructing wadm to manage the application
Arguments
client- The Client to use in order to send the request messagelattice- Optional lattice name that the application will be managed on, defaults todefaultmodel_name- Model name to deployversion- Version to deploy, defaults to deploying the latest “put” version