Module wash_lib::context

source ·
Types and methods for handling wash contexts, the configuration files for interacting with lattices

Modules

  • Implementations for managing contexts within a directory on a filesystem

Structs

Constants

Traits

  • A trait that can be implemented by any type that wants to load, save, and otherwise manage wash contexts (e.g. from a database or a config store

Functions