Parse wasmcloud.toml files which specify key information for building and signing WebAssembly modules and native capability provider binaries
Structs
- Common
Config - Configuration common among all project types & languages.
- Component
Config - DevConfig
- Configuration for development environments and/or DX related plugins
- DevManifest
Component Target - Target that specifies a single component in a given manifest path
- GoConfig
- Configuration related to Golang configuration
- Interface
Component Override - Interface-based overrides used for a single component
- Interface
Overrides - Configuration for imports that should be overridden
- OneOr
More Iterator - Iterator for
OneOrMore - Project
Config - Project configuration, normally specified in the root keys of a wasmcloud.toml file
- Provider
Config - Registry
Config - Registry
Pull Config - Configuration that governs pulling of packages from registries
- Registry
Pull Source Override - Information identifying a registry that can be pulled from
- Registry
Push Config - Rust
Config - Tiny
GoConfig - Wasmcloud
DotToml - The wasmcloud.toml specification format as de-serialization friendly project configuration data
- WitInterface
Spec - String that represents a specification of a WIT interface (normally used when specifying
InterfaceComponentOverrides)
Enums
- DevConfig
Spec - Specification for how to wire up configuration
- DevSecret
Spec - Specification for how to wire up secrets
- Language
Config - OneOr
More - Facilitates one of a given
Tor more (primarily for serde use) - Registry
Pull Source - Source for a registry pull
- Tiny
GoGarbage Collector - Tiny
GoScheduler - Type
Config - Wasm
Target
Functions
- load_
config - Gets the wasmCloud project (component or provider) config.