Structs
- Information related to an component stop
- Information related to an provider start
- Information related to an provider stop
Enums
- The potential outcomes of a function check on an event. Because we can pass events that are not applicable to the event we are looking for, we need the
NotApplicablevariant to skip these events. - The potential outcomes of an event that has been found. It can either succeed or fail. This enum should only be returned if we found the applicable event. If we did not find the event or another error occured, use the
Errvariant of aResultwrapping around this enum.
Functions
- Uses the NATS reciever to read events being published to the wasmCloud lattice event subject, up until the given timeout duration.
- Uses the NATS reciever to read events being published to the wasmCloud lattice event subject, up until the given timeout duration.
- Uses the NATS reciever to read events being published to the wasmCloud lattice event subject, up until the given timeout duration.
- Uses the NATS reciever to read events being published to the wasmCloud lattice event subject, up until the given timeout duration.